// beispiele/qcombobox/mywidget.cpp
#include "mywidget.h"
#include <QApplication>
#include <QMessageBox>
#include <QVariant>
#include <QTime>
#include <QDate>

// Neue Widget-Klasse vom eigentlichen Widget ableiten
MyWidget::MyWidget( QWidget *parent): QWidget(parent)  {
   combo1 = new QComboBox;
   combo1->setSizeAdjustPolicy(
      QComboBox::AdjustToContents );
   // Ein paar Daten
   QStringList wordList;
   wordList << "Data 1" << "Data 2"
            << "Data 3" << "Data 4";
   QVariant data(wordList);
   combo1->addItem( " --- Bitte auswhlen --- ");
   combo1->addItem( QIcon(QString("%1%2")
      .arg(QCoreApplication::applicationDirPath())
      .arg("/images/icon1.png")),
      "String-Liste", data );
   combo1->addItem( QIcon(QString("%1%2")
      .arg(QCoreApplication::applicationDirPath())
      .arg("/images/icon2.png")),
      "Programmstart", QVariant(QTime::currentTime()) );
   combo1->addItem( QIcon(QString("%1%2")
      .arg(QCoreApplication::applicationDirPath())
      .arg("/images/icon3.png")),
      "Datum", QVariant(QDate::currentDate () ) );
   // die blichen Boxen
   QVBoxLayout *vBox1 = new QVBoxLayout;
   vBox1->addWidget(combo1);

   combo2 = new QComboBox;
   // Elemente editierbar
   combo2->setEditable( true );
   // Elemente alphabetisch hinzufgen
   combo2->setInsertPolicy(
      QComboBox::InsertAlphabetically );
   but1 = new QPushButton("Hinzufgen");

   QVBoxLayout *vBox2 = new QVBoxLayout;
   vBox2->addWidget(combo2);
   vBox2->addWidget(but1);

    // Verpacken
    QGroupBox *groupBox1 = new QGroupBox(
       "Combo-Box 1 mit Daten (QVariant)" );
    groupBox1->setLayout(vBox1);
    QGroupBox *groupBox2 = new QGroupBox(
       "Combo-Box 2");
    groupBox2->setLayout(vBox2);

   connect( combo1, SIGNAL( activated ( int ) ),
            this, SLOT( checkCombo( int ) ) );
   connect( but1, SIGNAL( clicked() ),
            this, SLOT( addToCombo() ) );

   // ... und das Layout setzen
   QVBoxLayout* layout = new QVBoxLayout;
   layout->addWidget(groupBox1);
   layout->addWidget(groupBox2);
   setLayout(layout);
   setWindowTitle(tr("QComboBox - Demo"));
}

// Combo-Box auswerten
void MyWidget::checkCombo( int var ) {
   // Daten holen
   QVariant data = combo1->itemData(var);
   // Sind Daten vorhanden
   if( data != QVariant::Invalid ) {
       // Datentyp ermitteln
       switch( data.type() ) {
          case QVariant::StringList:  {
             QStringList list = data.toStringList();
             // String-List splitten
             QString msg = list.join("\n");
             QMessageBox::information(
                this, "Folgende Daten sind enthalten",
                msg, QMessageBox::Ok ) ;
          }
          break;
          case QVariant::Time: {
             QTime time = data.toTime();
             // String daraus machen
             QString msg = time.toString("hh:mm:ss");
             QMessageBox::information(
                this, "Uhrzeit des Programmstarts",
                msg, QMessageBox::Ok ) ;
          }
          break;
          case QVariant::Date:  {
             QDate date = data.toDate();
             // String daraus machen
             QString msg = date.toString(
                "Datum: (ddd) dd.MMM.20yy");
             QMessageBox::information(
                this, "Datum des Programmstarts",
                msg, QMessageBox::Ok ) ;
          }
          break;
       }
   }
}

void MyWidget::addToCombo() {
   // Eingegeben Text abholen
   QString select = combo2->currentText();
   // Wurde was eingegeben
   if( ! select.isEmpty() )
      // Ist der Text bereits vorhanden
      if( combo2->findText( select ) == -1 ) {
         // Text zur Combobox hinzufgen
         combo2->addItem(select);
      }
}

