// beispiele/qimage/mainWindow.cpp
#include <QtGui>
#include "mainWindow.h"

Window::Window() {
   QGridLayout *layout = new QGridLayout;
   transformedRenderAreas = new RenderArea;
   QPushButton *button1 = new QPushButton(
      tr("Speichern als JPG") );
   connect( button1, SIGNAL(clicked()),
            this, SLOT(saveImage()));
   QPushButton *button2 = new QPushButton(
      tr("Manipulieren"));
   connect( button2, SIGNAL(clicked()),
            this, SLOT(manipulateImage()));
   layout->addWidget(transformedRenderAreas, 0, 0);
   layout->addWidget(button1, 1, 0 );
   layout->addWidget(button2, 2, 0 );
   setLayout(layout);
   setWindowTitle(tr("QImage - Demo"));
}

void Window::saveImage() {
   transformedRenderAreas->saveJPG();
}

void Window::manipulateImage() {
   transformedRenderAreas->repaintImage();
}

RenderArea::RenderArea(QWidget *parent):QWidget(parent) {
   img = QImage(":/images/bild.png");
   manipulate = false;
}

QSize RenderArea::minimumSizeHint() const {
   return QSize(182, 182);
}

QSize RenderArea::sizeHint() const {
   return QSize(250, 250);
}

void RenderArea::paintEvent(QPaintEvent *event) {
   QPainter painter(this);
   painter.setRenderHint(
      QPainter::SmoothPixmapTransform, true );
   painter.fillRect(event->rect(), QBrush(Qt::white));
   painter.translate(30, 30);
   if( manipulate == false )
      painter.drawImage(0, 0, img );
   else {
      painter.save();
      drawShape(painter);
      painter.restore();
   }
}

void RenderArea::repaintImage() {
   manipulate = true;
   update();
}

void RenderArea::drawShape(QPainter &painter) {
   for( int line = 0; line < img.height(); line++ ) {
      QRgb* Pixel = reinterpret_cast<QRgb*>(
         img.scanLine(line) );
      for( int pos = 0; pos < img.width(); pos++ ) {
         int red = qRed(Pixel[pos]);
         int green = qGreen(Pixel[pos]);
         int blue = qBlue(Pixel[pos]);
         int alpha = qAlpha(Pixel[pos]);
         if( manipulate == true && red > 5 &&
             green > 5 && blue > 5 )
            Pixel[pos] = qRgba( 255, 255, 255, alpha );
         else
            Pixel[pos] = qRgba(red, green, blue, alpha );
      }
   }
   painter.drawImage(0, 0, img );
}

void RenderArea::saveJPG() {
   QImage out(img.size(), img.format()) ;
   for( int line = 0; line < img.height(); line++ ) {
      const QRgb* readPixel =  reinterpret_cast
         <const QRgb*>(img.scanLine(line));
      QRgb* Pixel = reinterpret_cast<QRgb*>(
         out.scanLine(line) );
      for( int pos = 0; pos < img.width(); pos++ ) {
         int red = qRed(readPixel[pos]);
         int green = qGreen(readPixel[pos]);
         int blue = qBlue(readPixel[pos]);
         int alpha = qAlpha(readPixel[pos]);
         if( manipulate == true && red > 10 &&
             green > 10 && blue > 10 )
            Pixel[pos] = qRgba( 255, 255, 255, alpha );
         else
            Pixel[pos] = qRgba( red, green, blue, alpha);
      }
   }
   out.save(QString("%1%2")
      .arg(QCoreApplication::applicationDirPath())
      .arg("/bild_neu.jpg"), "JPG");
}

