// beispiele/qlineedit/mywidget.cpp
#include "mywidget.h"
#include <QApplication>
#include <QRadioButton>
#include <QMessageBox>
#include <QIntValidator>
#include <QCompleter>

// Neue Widget-Klasse vom eigentlichen Widget ableiten
MyWidget::MyWidget( QWidget *parent): QWidget(parent)  {
   edit1 = new QLineEdit;
   // Autovervollstndigung verwenden
   QStringList wordList;
   wordList << "Trolltech" << "Wolf"
            << "Auto" << "Automobil";
   QCompleter *completer = new QCompleter(wordList,this);
   completer->setCaseSensitivity(Qt::CaseInsensitive);
   edit1->setCompleter(completer);

   radio01 = new QRadioButton("Normal");
   radio01->setChecked(true);
   radio02 = new QRadioButton("Password");
   radio03 = new QRadioButton("PasswordEchoOnEdit");
   radio04 = new QRadioButton("No Echo");
   but1 = new QPushButton("Auswerten");

   // die blichen Boxen
   QVBoxLayout *vBox1 = new QVBoxLayout;
   vBox1->addWidget(edit1);
   vBox1->addWidget(radio01);
   vBox1->addWidget(radio02);
   vBox1->addWidget(radio03);
   vBox1->addWidget(radio04);
   vBox1->addWidget(but1);

   edit2 = new QLineEdit;
   edit2->setAlignment(Qt::AlignHCenter);
   radio05 = new QRadioButton("Integer (Validator)");
   // Integer-Validator verwenden
   edit2->setValidator(new QIntValidator(edit2));

   radio05->setChecked(true);
   radio06 = new QRadioButton("Double (Validator)");
   radio07 = new QRadioButton(
       "Regex (Validator) (-9999 bis 9999)" );
   radio08 = new QRadioButton(
      "Datum (Maske) (dd.mm.yyyy)" );
   radio09 = new QRadioButton(
      "IP-Adresse (Maske) (000.000.000.000)" );
   radio10 = new QRadioButton("Read-Only");

   QVBoxLayout *vBox2 = new QVBoxLayout;
   vBox2->addWidget(edit2);
   vBox2->addWidget(radio05);
   vBox2->addWidget(radio06);
   vBox2->addWidget(radio07);
   vBox2->addWidget(radio08);
   vBox2->addWidget(radio09);
   vBox2->addWidget(radio10);

   connect( radio01, SIGNAL( toggled(bool) ),
            this, SLOT( changeEcho(bool) ) );
   connect( radio02, SIGNAL( toggled(bool) ),
            this, SLOT( changeEcho(bool) ) );
   connect( radio03, SIGNAL( toggled(bool) ),
            this, SLOT( changeEcho(bool) ) );
   connect( radio04, SIGNAL( toggled(bool) ),
            this, SLOT( changeEcho(bool) ) );
   connect( radio05, SIGNAL( toggled(bool) ),
            this, SLOT( setValidMask(bool) ) );
   connect( radio06, SIGNAL( toggled(bool) ),
            this, SLOT( setValidMask(bool) ) );
   connect( radio07, SIGNAL( toggled(bool) ),
            this, SLOT( setValidMask(bool) ) );
   connect( radio08, SIGNAL( toggled(bool) ),
            this, SLOT( setValidMask(bool) ) );
   connect( radio09, SIGNAL( toggled(bool) ),
            this, SLOT( setValidMask(bool) ) );
   connect( radio10, SIGNAL( toggled(bool) ),
            this, SLOT( setValidMask(bool) ) );
   connect( but1, SIGNAL( clicked() ),
            this, SLOT( readText() ) );

     // Verpacken
     QGroupBox *groupBox1 = new QGroupBox(
           "Echo-Demo");
     groupBox1->setLayout(vBox1);
     QGroupBox *groupBox2 = new QGroupBox(
           "QLineEdit - Demo");
     groupBox2->setLayout(vBox2);

     // ... und das Layout setzen
     QVBoxLayout* layout = new QVBoxLayout;
     layout->addWidget(groupBox1);
     layout->addWidget(groupBox2);
     setLayout(layout);
     setWindowTitle(tr("QLineEdit - Demo"));
}

// Textausgaben setzen
void MyWidget::changeEcho( bool b ) {
   if( radio01->isChecked())
      edit1->setEchoMode(QLineEdit::Normal);
   if( radio02->isChecked())
      edit1->setEchoMode(QLineEdit::Password);
   if( radio03->isChecked())
      edit1->setEchoMode(QLineEdit::PasswordEchoOnEdit);
   if( radio04->isChecked())
      edit1->setEchoMode(QLineEdit::NoEcho);
}

// Neue Maske bzw. Validator setzen
void MyWidget::setValidMask( bool b ) {
   edit2->setInputMask("");
   edit2->setReadOnly(false);
   if( radio05->isChecked())
      edit2->setValidator(new QIntValidator(edit2));
   else if( radio06->isChecked())
      edit2->setValidator(new QDoubleValidator(edit2));
   else if( radio07->isChecked()) {
      // Integerwert zwischen -9999 und 9999
      QRegExp rx("-?[1-9]\\d{0,3}");
      QValidator *validator =
         new QRegExpValidator(rx, this);
      edit2->setValidator(validator);
   }
   else if( radio08->isChecked())
      edit2->setInputMask("00-00-0000");
   else if( radio09->isChecked())
      edit2->setInputMask("000.000.000.000;_");
   else if( radio10->isChecked())
      edit2->setReadOnly(true);
 }

 // Eingegebenen Text auswerten
 void MyWidget::readText( ) {
    QMessageBox::information(
       this, "Folgender Text wurde eingegeben",
       edit1->text(), QMessageBox::Ok ) ;
 }

