// beispiele/qlistwidget/iconselector.cpp
#include <QtGui>
#include "iconselector.h"

IconSelector::IconSelector(
      const QMap<int, QString> &iconMap,
      QWidget *parent) : QDialog(parent) {
   id = -1;
   listWidget = new QListWidget;
   listWidget->setIconSize(QSize(25, 25));

   QMapIterator<int, QString> Icon(iconMap);
   while (Icon.hasNext()) {
      Icon.next();
      QListWidgetItem *item = new QListWidgetItem(
         Icon.value(), listWidget);
      item->setIcon(String2Icon(Icon.value()));
      item->setData(Qt::UserRole, Icon.key());
      if( Icon.key() % 2 )
         item->setBackground(QBrush(Qt::lightGray));
      else
         item->setBackground(QBrush(Qt::yellow));
   }
   okButton = new QPushButton(tr("OK"));
   okButton->setDefault(true);
   cancelButton = new QPushButton(tr("Beenden"));

   connect( okButton, SIGNAL(clicked()),
            this, SLOT(accept()));
   connect( cancelButton, SIGNAL(clicked()),
            this, SLOT(reject()));
   connect( listWidget,
            SIGNAL(itemClicked ( QListWidgetItem*)),
            this, SLOT(curItem(QListWidgetItem*)));
   QHBoxLayout *buttonLayout = new QHBoxLayout;
   buttonLayout->addStretch();
   buttonLayout->addWidget(okButton);
   buttonLayout->addWidget(cancelButton);

   QVBoxLayout *mainLayout = new QVBoxLayout;
   mainLayout->addWidget(listWidget);
   mainLayout->addLayout(buttonLayout);
   setLayout(mainLayout);
   setWindowTitle(tr("Icons auswhlen"));
}

void IconSelector::done(int result)  {
   id = -1;
   if (result == QDialog::Accepted) {
      QListWidgetItem *item = listWidget->currentItem();
      if (!item)
         return;
      id = item->data(Qt::UserRole).toInt();
      QString itemText = item->text();
      itemText.append(tr(" (ID: "));
      itemText.append(QString::number(id));
      itemText.append(tr(")"));
      QMessageBox msgBox(
         QMessageBox::NoIcon,
         tr("Ihre Auswahl:"),
         itemText,
         QMessageBox::Ok );
      msgBox.setIconPixmap(
         (item->icon()).pixmap(22, 22));
      msgBox.exec();
   }
   else
      QDialog::done(result);
}

void IconSelector::curItem( QListWidgetItem *item ) {
   if (!item)
      return;
   id = item->data(Qt::UserRole).toInt();
   QString itemText = item->text();
   itemText.append(tr(" (ID: "));
   itemText.append(QString::number(id));
   itemText.append(tr(")"));
   QMessageBox msgBox(
      QMessageBox::NoIcon,
      tr("Ihre Auswahl:"),
      itemText,
      QMessageBox::Ok );
   msgBox.setIconPixmap((item->icon()).pixmap(22, 22));
   msgBox.exec();
}

QIcon IconSelector::String2Icon(const QString &iconName){
   QString fileName = QString("%1%2")
      .arg(QCoreApplication::applicationDirPath())
      .arg("/images/") + iconName.toLower();
   return QIcon(fileName);
}

