// beispiele/qscrollarea/mainwindow.cpp
#include <QtGui>
#include <QMenu>
#include "mainwindow.h"

// Konstruktor
MainWindow::MainWindow()  {
   label = new QLabel;
   label->setSizePolicy(
      QSizePolicy::Ignored, QSizePolicy::Ignored);
   label->setScaledContents(true);
   
   QImage image(QString("%1%2")
      .arg(QCoreApplication::applicationDirPath())
      .arg("/images/krokodil.png"));
   label->setPixmap(QPixmap::fromImage(image));

   area = new QScrollArea;
   area->setBackgroundRole(QPalette::Dark);
   area->setWidget(label);
   setCentralWidget(area);
   createActions();
   scaleFactor = 1.0;

   QMenu* viewMenu = new QMenu(tr("&Ansicht"), this);
   viewMenu->addAction(zoomInAct);
   viewMenu->addAction(zoomOutAct);
   menuBar()->addMenu(viewMenu);
   setWindowTitle(tr("QScrollArea - Demonstration"));
}

void MainWindow::createActions() {
  zoomInAct = new QAction(tr("Zoom &In (25%)"), this);
  zoomInAct->setShortcut(tr("Ctrl++"));
  connect( zoomInAct, SIGNAL(triggered()),
           this, SLOT(zoomIn()) );
  zoomOutAct = new QAction(tr("Zoom &Out (25%)"), this);
  zoomOutAct->setShortcut(tr("Ctrl+-"));
  zoomOutAct->setEnabled(true);
  connect( zoomOutAct, SIGNAL(triggered()),
           this, SLOT(zoomOut()) );
}

void MainWindow::zoomIn() {
   scaleImage(1.25);
}

void MainWindow::zoomOut() {
   scaleImage(0.75);
}

// Bild (Label) skalieren
void MainWindow::scaleImage(double factor)  {
   scaleFactor *= factor;
   label->resize(scaleFactor * label->pixmap()->size());
   // horiz. und verti. Scrollbalken mittig setzen
   adjustScrollBar(area->horizontalScrollBar(), factor);
   adjustScrollBar(area->verticalScrollBar(), factor);
   // Max. und Min. Grenze fr das Skalieren
   zoomInAct->setEnabled(scaleFactor < 3.0);
   zoomOutAct->setEnabled(scaleFactor > 0.333);
}

// Scrollbar mittig setzen
void MainWindow::adjustScrollBar(
       QScrollBar *scrollBar, double factor)  {
   scrollBar->setValue(
      int(factor * scrollBar->value()
      + ((factor - 1) * scrollBar->pageStep()/2)));
}

