// beispiele/qtabwidget/mywidget.cpp
#include "mywidget.h"
#include <QApplication>
#include <QMessageBox>

// Neue Widget-Klasse vom eigentlichen Widget ableiten
MyWidget::MyWidget( QWidget *parent): QWidget(parent)  {
   // Zwei Radio-Buttons erzeugen
   rbutton1=new QRadioButton("Style: Rounded (default)");
   rbutton2 = new QRadioButton ("Style: Triangular");
   // Button vorbelegen
   rbutton1->setChecked(true);
   // Drei Check-Button erzeugen
   cbutton1 = new QCheckBox ("Icons setzen");
   cbutton2 = new QCheckBox ("Erstes Tab deaktivieren");
   cbutton3 = new QCheckBox ("Tooltips verwenden");
   // Vier normale Buttons erzeugen ...
   pbutton1 = new QPushButton("Norden");
   pbutton2 = new QPushButton("Sden");
   pbutton3 = new QPushButton("Westen");
   pbutton4 = new QPushButton("Osten");
   // ... und daraus toggled Buttons machen
   pbutton1->setCheckable(true);
   pbutton2->setCheckable(true);
   pbutton3->setCheckable(true);
   pbutton4->setCheckable(true);
   // ... nur einer der vier Buttons darf
   // niedergerckt sein
   pbutton1->setAutoExclusive(true);
   pbutton2->setAutoExclusive(true);
   pbutton3->setAutoExclusive(true);
   pbutton4->setAutoExclusive(true);
   // Drei Group-Boxen mit Label erzeugen
   groupBox1 = new QGroupBox("Look && Feel");
   groupBox2 = new QGroupBox("Attribute");
   groupBox3 = new QGroupBox("Position");
   // Drei vertikale Layout-Boxen erzeugen
   vBox1 = new QVBoxLayout;
   vBox2 = new QVBoxLayout;
   vBox3 = new QVBoxLayout;
   // Radio-Buttons in Layoutbox vBox1 packen
   vBox1->addWidget(rbutton1);
   vBox1->addWidget(rbutton2);
   // Check-Buttons in Layoutbox vBox2 packen
   vBox2->addWidget(cbutton1);
   vBox2->addWidget(cbutton2);
   vBox2->addWidget(cbutton3);
   // Toggled Buttons in Layoutbox vBox3 packen
   vBox3->addWidget(pbutton1);
   vBox3->addWidget(pbutton2);
   vBox3->addWidget(pbutton3);
   vBox3->addWidget(pbutton4);
   // Stretch (1) fr alle Layoutboxen hinzufgen
   vBox1->addStretch(1);
   vBox2->addStretch(1);
   vBox3->addStretch(1);
   // Group-Boxen ohne Rahmen darstellen
   groupBox1->setFlat(true);
   groupBox2->setFlat(true);
   groupBox3->setFlat(true);
   // Layout der einzelnen Group-Boxen setzen
   groupBox1->setLayout(vBox1);
   groupBox2->setLayout(vBox2);
   groupBox3->setLayout(vBox3);
   // Neue Tab-Leiste erzeugen
   tab = new QTabWidget;
   // Groupbox mit Radio-Buttons als
   // Seitenbreich hinzufgen
   tab->addTab(groupBox1, "Look && Feel" );
   // Groupbox mit Check-Buttons als
   // Seitenbereich hinzufgen
   tab->addTab(groupBox2, "Attribute" );
   //Groupbox mit toggled-Buttons hinzufgen
   tab->addTab(groupBox3, "Position" );
   // Ausrichtung der Tab-Leiste berprfen, um
   // entsprechenden toogled "niederzudrcken"
   if( tab->tabPosition() == QTabWidget::North )
       pbutton1->setChecked(true);
   else if( tab->tabPosition() == QTabWidget::South )
       pbutton2->setChecked(true);
   else if( tab->tabPosition() == QTabWidget::West )
       pbutton3->setChecked(true);
   else if( tab->tabPosition() == QTabWidget::East )
       pbutton4->setChecked(true);
   // Signal-Slot-Verbindung fr Radio-Buttons
   connect( rbutton1, SIGNAL( toggled(bool) ),
            this, SLOT( changeTabStyle(bool) ) );
   connect( rbutton2, SIGNAL( toggled(bool) ),
            this, SLOT( changeTabStyle(bool) ) );
   // Signal-Slot-Verbindung fr Check-Buttons
   connect( cbutton1, SIGNAL( stateChanged(int) ),
            this, SLOT( setTabAttribute(int) ) );
   connect( cbutton2, SIGNAL( stateChanged(int) ),
            this, SLOT( setTabAttribute(int) ) );
   connect( cbutton3, SIGNAL( stateChanged(int) ),
            this, SLOT( setTabAttribute(int) ) );
   // Signal-Slot-Verbindung fr toogled-Buttons
   connect( pbutton1, SIGNAL( toggled(bool) ),
            this, SLOT( setPosition(bool) ) );
   connect( pbutton2, SIGNAL( toggled(bool) ),
            this, SLOT( setPosition(bool) ) );
   connect( pbutton3, SIGNAL( toggled(bool) ),
            this, SLOT( setPosition(bool) ) );
   connect( pbutton4, SIGNAL( toggled(bool) ),
            this, SLOT( setPosition(bool) ) );
   // Signal-Slot-Verbindung fr die Tab-Leiste
   connect( tab, SIGNAL( currentChanged( int  ) ),
            this, SLOT( getCurrentPosition( int ) ) );
   // Ein Layout-Widget fr das Tab-Widget
   // brauchen wir noch
   QVBoxLayout* layout = new QVBoxLayout;
   layout->addWidget(tab);
   setLayout(layout);
   setWindowTitle("QTabWidget- Demo");
 }

 // Slot: Radio-Buttons auswerten
 void MyWidget::changeTabStyle(bool b) {
    if( rbutton1->isChecked())
       tab->setTabShape(QTabWidget::Rounded);
    if( rbutton2->isChecked())
       tab->setTabShape(QTabWidget::Triangular);
 }

 // Slot: Check-Buttons auswerten
 void MyWidget::setTabAttribute(int a) {
    if( cbutton1->isChecked()) {
       int i;
       for(i=0; i < tab->count(); ++i) {
          QString Icon =
             QString("/images/icon%1.png").arg(i+1);
          tab->setTabIcon( i, QIcon(QString("%1%2")
             .arg(QCoreApplication::applicationDirPath())
             .arg(Icon)));
       }
    }
    if( cbutton2->isChecked() ) {
       tab->setTabEnabled(0, false );
    }
    else if(! cbutton2->isChecked()) {
       tab->setTabEnabled(0, true );
    }
    if( cbutton3->isChecked() ) {
       tab->setTabToolTip(
          0, "Das Look & Feel vernden" );
       tab->setTabToolTip(
          1, "Gngige Attribute hinzufgen" );
       tab->setTabToolTip(
          2, "Position vom Tab verndern" );
    }
    else if (!cbutton3->isChecked()){
       tab->setTabToolTip ( 0, "" );
       tab->setTabToolTip ( 1, "" );
       tab->setTabToolTip ( 2, "" );
    }
 }

 // Slot: toogled Buttons auswerten
 void MyWidget::setPosition(bool b) {
      if( pbutton1->isChecked() )
         tab->setTabPosition(QTabWidget::North);
      else if( pbutton2->isChecked() )
         tab->setTabPosition(QTabWidget::South);
      else if( pbutton3->isChecked() )
         tab->setTabPosition(QTabWidget::West);
      else if( pbutton4->isChecked() )
         tab->setTabPosition(QTabWidget::East);
 }

 // Slot: Tab wurde gewechselt
 void MyWidget::getCurrentPosition(int pos) {
    QString msg =
       QString("Zu Tab %1 gewechselt").arg(
          tab->tabText(pos) );
    QMessageBox::information(
       this,"Tab gewechsel",msg,QMessageBox::Ok);
 }

