// beispiele/qtextedit/mywidget.cpp
#include "mywidget.h"
#include <QApplication>
#include <QMessageBox>
#include <QFont>
#include <QFile>
#include <QMenu>
#include <QMenuBar>
#include <QFileDialog>
#include <QFontDialog>
#include <QColorDialog>
#include <QInputDialog>

// Neue Widget-Klasse vom eigentlichen Widget ableiten
MyWidget::MyWidget( QMainWindow *parent) :
        QMainWindow(parent)  {
     editor = new QTextEdit;
     QString html_text(
        "QTextEdit unterst&uuml;tzt <b>HTML-Tags</b> zur"
        "Formatierung von <i>Text</i>.<br><br><ul>"
        "<li>Aufz&auml;hlpunkt1</li>"
        "<li>Aufz&auml;hlpunkt2</li>"
        "<ul><li>Unterpunkt2</li></ul>"
        "<li>Aufz&auml;hlpunkt3</li></ul><br>"
        "<hr style=\"width: 100%; height: 2px;\"><br>"
        "<table border=\"1\"><tbody><tr><td>"
        "<b>Werte</b></td><td><b>Beschreibung</b></td>"
        "</tr><tr><td>fault_xxx</td><td>Fehler</td>"
        "</tr></tbody></table><br><img alt=\"Ein Bild\" "
        "src=\"images/icon.png\">");

     editor->setHtml(html_text);
     // Text nach 80 Spalten brechen
     editor->setLineWrapMode(
        QTextEdit::FixedColumnWidth );
     editor->setLineWrapColumnOrWidth (80);
     editor->setWordWrapMode (
        QTextOption::WrapAtWordBoundaryOrAnywhere );

     // Das Men
     QMenu *fileMenu = new QMenu(tr("&Datei"), this);
     menuBar()->addMenu(fileMenu);
     fileMenu->addAction(
        tr("&Neu"), this, SLOT(newFile()),
        QKeySequence(tr("Ctrl+N", "Datei|Neu")));
     fileMenu->addAction(
        tr("&Oeffnen..."), this, SLOT(openFile()),
        QKeySequence(tr("Ctrl+O", "Datei|Oeffnen")));
     fileMenu->addAction(
        tr("Be&enden"), qApp, SLOT(quit()),
        QKeySequence(tr("Ctrl+E", "Datei|Beenden")));
     QMenu *workMenu = new QMenu(
        tr("&Bearbeiten"), this);
     menuBar()->addMenu(workMenu);
     workMenu->addAction(
        tr("&Suchen"), this, SLOT(search()),
        QKeySequence(tr("Ctrl+S", "Bearbeiten|Suchen")));
     QMenu *viewMenu = new QMenu(tr("&Ansicht"), this);
     menuBar()->addMenu(viewMenu);
     viewMenu->addAction(
       tr("&Schriftart ndern"), this,SLOT(changeFont()),
       QKeySequence(
          tr("Ctrl+F", "Ansicht|Schriftart ndern") ) );
     viewMenu->addAction(
        tr("S&chriftfarbe ndern"), this,
        SLOT(changeColor()),
        QKeySequence(
           tr("Ctrl+C", "Ansicht|Schriftfarbe ndern")));
     setCentralWidget(editor);
     setWindowTitle("QTextEdit - Demo");
}

// Datei ffnen und im Editor anzeigen
void MyWidget::openFile() {
     QString fileName;
     fileName = QFileDialog::getOpenFileName(
        this, tr("Datei ffnen"), "",
        "C++ Dateien (*.cpp *.h);;"
        "Text-Dateien (*.txt);;"
        "Alle Dateien (*.*)" );
     if (!fileName.isEmpty()) {
        QFile file(fileName);
        if (file.open(QFile::ReadOnly | QFile::Text))
           editor->setPlainText(file.readAll());
     }
}

// Inhalt des Editors lschen
void MyWidget::newFile( ) {
    editor->clear();
}

// Schriftart ndern
void MyWidget::changeFont( ) {
    editor->setFont(
       QFontDialog::getFont(0, editor->font() ) );
}

// Farbe von markierten Text ndern
void MyWidget::changeColor( ) {
    editor->setTextColor(QColorDialog::getColor());
}

// Im Editor nach einer bestimmten Textfolge suchen
void MyWidget::search( ) {
   bool ok;
   QString text = QInputDialog::getText(
      this, "Suchdialog", "Text zur Suche eingeben :",
      QLineEdit::Normal, "Suche eingeben", &ok );
   if (ok && !text.isEmpty())
      editor->find(text);
}

